Class: FFIGen::Clang::CompletionResult
- Inherits:
-
FFI::Struct
- Object
- FFI::Struct
- FFIGen::Clang::CompletionResult
- Defined in:
- lib/ffi_gen/clang.rb
Overview
A single result of code completion.
Fields:
:cursor_kind ::
(Symbol from _enum_cursor_kind_) The kind of entity that this completion refers to.
The cursor kind will be a macro, keyword, or a declaration (one of the
*Decl cursor kinds), describing the entity that the completion is
referring to.
\todo In the future, we would like to provide a full cursor, to allow
the client to extract additional information from declaration.
:completion_string ::
(FFI::Pointer(CompletionString)) The code-completion string that describes how to insert this
code-completion result into the editing buffer.