Class: FFIGen::Clang::SourceLocation
- Inherits:
-
FFI::Struct
- Object
- FFI::Struct
- FFIGen::Clang::SourceLocation
- Defined in:
- lib/ffi_gen/clang.rb
Overview
Identifies a specific source location within a translation unit.
Use clang_getExpansionLocation() or clang_getSpellingLocation() to map a source location to a particular file, line, and column.
Fields:
:ptr_data ::
(Array<FFI::Pointer(*Void)>)
:int_data ::
(Integer)